@@ -117,6 +117,14 @@ setMethod(
   }
 )
 
+setMethod(
+    "show_implementation", signature(object = "system_stochastic_adjustment"),
+    function(object) {
+        callNextMethod(object)
+        show_implementation(object@price_equation)
+    }
+)
+
 setMethod(
   "get_likelihood_variables", signature(object = "system_stochastic_adjustment"),
   function(object) {
